@@ -12,6 +12,6 @@ __author__ = 'Matthew Evans'
 __maintainer__ = 'Matthew Evans'
 
 
-from matador.calculators.castep import CastepCalculator
+from .castep import CastepCalculator
 # from matador.calculators.quantum_espresso import QuantumEspressoCalculator
 # from matador.calculators.ase import ASECalculator
