@@ -195,6 +195,18 @@ class Crystal(DataContainer):
 
         return repr_string
 
+    def update(self, data):
+        """ Update the underlying `self._data` dictionary
+        with the passed data.
+
+        """
+        self._data.update(data)
+
+    def print_sites(self):
+        for site in self:
+            print(site)
+        print('---')
+
     def set_positions(self, new_positions, fractional=True):
         if len(new_positions) != self.num_atoms:
             raise RuntimeError('Cannot change size of positions array!')
@@ -222,16 +234,16 @@ class Crystal(DataContainer):
             if 'site_occupancy' in self._data:
                 if len(self._data['site_occupancy']) == len(self._data['atom_types']):
                     site_data['site_occupancy'] = self._data['site_occupancy'][ind]
-            if 'chemical_shifts' in self._data:
-                if len(self._data['chemical_shifts']) == len(self._data['atom_types']):
-                    site_data['magres_shift'] = self._data['chemical_shifts'][ind]
+            if 'chemical_shielding_isos' in self._data:
+                if len(self._data['chemical_shielding_isos']) == len(self._data['atom_types']):
+                    site_data['chemical_shielding_iso'] = self._data['chemical_shielding_isos'][ind]
             if 'magnetic_shielding_tensor' in self._data:
-                if len(self._data['magnetic_shielding_tensor']) == len(self._data['atom_types']):
-                    site_data['magres_shielding'] = self._data['magnetic_shielding_tensor'][ind]
-            if 'chemical_shift_anisos' in self._data:
-                site_data['magres_aniso'] = self._data['chemical_shift_anisos'][ind]
-            if 'chemical_shift_asymmetries' in self._data:
-                site_data['magres_asymm'] = self._data['chemical_shift_asymmetries'][ind]
+                if len(self._data['magnetic_shielding_tensors']) == len(self._data['atom_types']):
+                    site_data['magnetic_shielding_tensor'] = self._data['magnetic_shielding_tensors'][ind]
+            if 'chemical_shielding_anisos' in self._data:
+                site_data['chemical_shielding_aniso'] = self._data['chemical_shielding_anisos'][ind]
+            if 'chemical_shielding_asymmetries' in self._data:
+                site_data['chemical_shielding_asymmetry'] = self._data['chemical_shielding_asymmetries'][ind]
             if 'atomic_spins' in self._data:
                 site_data['spin'] = self._data['atomic_spins'][ind]
             if 'voronoi_substructure' in self._data:
@@ -455,7 +467,7 @@ class Crystal(DataContainer):
 
         """
         from matador.utils.ase_utils import doc2ase
-        return doc2ase(self, add_keys_to_info=False)
+        return doc2ase(self, add_keys_to_info=True)
 
     @property
     def pmg_structure(self):
@@ -466,6 +478,16 @@ class Crystal(DataContainer):
         from matador.utils.pmg_utils import doc2pmg
         return doc2pmg(self)
 
+    @classmethod
+    def from_ase(cls, atoms):
+        from matador.utils.ase_utils import ase2dict
+        return ase2dict(atoms, as_model=True)
+
+    @classmethod
+    def from_pmg(cls, pmg):
+        from matador.utils.pmg_utils import pmg2dict
+        return pmg2dict(pmg, as_model=True)
+
     @property
     def coordination_lists(self):
         """ Returns a dictionary containing pairs of elements and the
